Checks a string value to see if it's a valid AAGI colour and converts it to the corresponding hexadecimal colour code. This is done by checking for an "AAGI " prefix in the string, as all valid colours from AAGIPalettes will have this.
Checks a string value to see if it's a valid AAGI colour and converts it to the corresponding hexadecimal colour code. This is done by checking for an "AAGI " prefix in the string, as all valid colours from AAGIPalettes will have this.